# multi-slit-solar-explorer

[![tests](https://github.com/sun-data/multi-slit-solar-explorer/actions/workflows/tests.yml/badge.svg)](https://github.com/sun-data/multi-slit-solar-explorer/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/sun-data/multi-slit-solar-explorer/graph/badge.svg?token=tBcex8q72g)](https://codecov.io/gh/sun-data/multi-slit-solar-explorer)
[![Black](https://github.com/sun-data/multi-slit-solar-explorer/actions/workflows/black.yml/badge.svg)](https://github.com/sun-data/multi-slit-solar-explorer/actions/workflows/black.yml)
[![Ruff](https://github.com/sun-data/multi-slit-solar-explorer/actions/workflows/ruff.yml/badge.svg)](https://github.com/sun-data/multi-slit-solar-explorer/actions/workflows/ruff.yml)
[![Documentation Status](https://readthedocs.com/projects/sun-data-multi-slit-solar-explorer/badge/?version=latest&token=04d5b4b840efc110f0858920dcef5f0c7d420092904885488a4518e1621df298)](https://sun-data-multi-slit-solar-explorer.readthedocs-hosted.com/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/multi-slit-solar-explorer.svg)](https://badge.fury.io/py/multi-slit-solar-explorer)

A Python library which models the optical system of the Multi-Slit Solar Explorer, a NASA satellite which measures the spectrum of the solar corona over a wide field of view with high spatial, spectral, and temporal resolution.
